/*
  Copyright (C) 2011 Alessandro Bugatti (alessandro.bugatti@istruzione.it)

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/*! \file
 *  \brief Gruppo che contiene l'interfaccia del gioco 2048
 *  \author Alessandro Bugatti
 *  \version 0.1
 *  \date  Creazione 05/04/2014
 *  \date  Ultima modifica 05/04/2014
 */


#ifndef DUEMILA48BOX_H
#define DUEMILA48BOX_H

#include <FL/Fl.H>
#include <FL/Fl_Group.H>
#include <FL/Fl_box.H>
#include <FL/fl_ask.H>
#include <cstdio>
#include <map>

using namespace std;

#include "duemila48game.h"

class Duemila48box : public Fl_Group
{
    Fl_Box *tile[4][4];
    Duemila48Game game;
    void aggiorna_tabellone();
    map <int, Fl_Color> colori;
public:
    Duemila48box(int X,int Y,int W,int H,const char *L=0) : Fl_Group(X,Y,W,H,L) {
        box(FL_BORDER_BOX); color(46);          // dark bg color for group
        for (int i = 0; i < 4; i++)
            for (int j = 0; j < 4; j++)
            {
                tile[i][j] = new Fl_Box(i*W/4+2, j*H/4+2, W/4-4, H/4-4);
                tile[i][j]->color(fl_rgb_color(205, 193, 181));
                tile[i][j]->box(FL_EMBOSSED_BOX);
                tile[i][j]->labelfont(FL_HELVETICA_BOLD);
                tile[i][j]->labelsize(42);
            }
        end();
        colori[2] = fl_rgb_color(238, 228, 218);
        colori[4] = fl_rgb_color(236, 224, 202);
        colori[8] = fl_rgb_color(245, 164, 101);
        colori[16] = fl_rgb_color(245, 149, 101);
        colori[32] = fl_rgb_color(245, 124, 95);
        colori[64] = fl_rgb_color(246, 93, 59);
        colori[128] = fl_rgb_color(237, 206, 113);
        colori[256] = fl_rgb_color(237, 204, 99);
        colori[512] = fl_rgb_color(237, 211, 92);
        colori[1024] = fl_rgb_color(237, 197, 63);
        colori[2048] = fl_rgb_color(238, 194, 46);
        game.aggiungi_tessera();
        game.aggiungi_tessera();
        aggiorna_tabellone();
    }

    int handle(int e);

};

#endif // DUEMILA48BOX_H
